@@ -93,8 +93,15 @@ class TestLonSLT():
                                      slt_name='slt')
 
         # This works because test instrument longitude ranges from 0-360 deg
-        assert (abs(self.py_inst['slt'].values
-                    - self.py_inst['longitude'].values / 15.0)).max() < 1.0e-6
+        # Testing the difference in periodic space to guard against changes
+        # in numerical precision across platforms.
+        diff = abs(self.py_inst['slt'].values
+                   - self.py_inst['longitude'].values / 15.0)
+        diff_radians = diff * np.pi / 12.0
+        sin_diff = np.sin(diff_radians)
+        cos_diff = np.cos(diff_radians)
+        assert np.max(np.abs(sin_diff)) < 1.0e-6
+        assert np.min(np.abs(cos_diff)) > 1.0 - 1.0e-6
 
     @pytest.mark.parametrize("name", ["testing", "testing_xarray"])
     def test_calc_solar_local_time_inconsistent_keywords(self, name, caplog):
